@@ -23,8 +23,14 @@ class QuantityConverter(Converter):
         return node
 
     def from_yaml_tree(self, node, tag, ctx):
+        # numpy 2.0 changed behavior for copy where an error is produced
+        # if False and a copy is required (previously there was no error)
+        # astropy 6.1 changed Quantity in a similar way
+        import numpy as np
         from astropy.units import Quantity
 
+        copy = None if np.lib.NumpyVersion(np.__version__) >= "2.0.0b1" else False
+
         value = node["value"]
         dtype = node.get("datatype", None)
         if isinstance(value, NDArrayType):
@@ -33,4 +39,4 @@ class QuantityConverter(Converter):
             value = value._make_array()
             dtype = value.dtype
 
-        return Quantity(value, unit=node["unit"], copy=False, dtype=dtype)
+        return Quantity(value, unit=node["unit"], copy=copy, dtype=dtype)
