@@ -3,10 +3,8 @@ This module builds all of the ASDF extensions which will be registered by `asdf_
 via an ``entry-point`` in the ``pyproject.toml`` file.
 """
 
-from asdf.extension import ManifestExtension
-from astropy.utils import minversion
+from asdf.extension import Extension, ManifestExtension
 
-from ._manifest import CompoundManifestExtension
 from .converters.coordinates.angle import AngleConverter, LatitudeConverter, LongitudeConverter
 from .converters.coordinates.earth_location import EarthLocationConverter
 from .converters.coordinates.frame import FrameConverter, LegacyICRSConverter
@@ -14,6 +12,7 @@ from .converters.coordinates.representation import RepresentationConverter
 from .converters.coordinates.sky_coord import SkyCoordConverter
 from .converters.coordinates.spectral_coord import SpectralCoordConverter
 from .converters.fits.fits import AsdfFitsConverter, AstropyFitsConverter
+from .converters.nddata.uncertainty import UncertaintyConverter
 from .converters.table.table import AsdfTableConverter, AstropyTableConverter, ColumnConverter, NdarrayMixinConverter
 from .converters.time.time import TimeConverter
 from .converters.time.time_delta import TimeDeltaConverter
@@ -32,6 +31,8 @@ from .converters.unit.equivalency import EquivalencyConverter
 from .converters.unit.magunit import MagUnitConverter
 from .converters.unit.quantity import QuantityConverter
 from .converters.unit.unit import UnitConverter
+from .converters.wcs.slicedwcs import SlicedWCSConverter
+from .converters.wcs.wcs import WCSConverter
 
 __all__ = [
     "TRANSFORM_CONVERTERS",
@@ -39,11 +40,12 @@ __all__ = [
     "TRANSFORM_EXTENSIONS",
     "COORDINATES_CONVERTERS",
     "ASTROPY_CONVERTERS",
-    "COORDINATES_EXTENSION",
+    "COORDINATES_EXTENSIONS",
     "ASTROPY_EXTENSIONS",
     "CORE_CONVERTERS",
     "CORE_MANIFEST_URIS",
     "CORE_EXTENSIONS",
+    "UNIT_EXTENSIONS",
 ]
 
 TRANSFORM_CONVERTERS = [
@@ -385,20 +387,16 @@ TRANSFORM_CONVERTERS = [
     # astropy.modeling.bounding_box
     ModelBoundingBoxConverter(),
     CompoundBoundingBoxConverter(),
+    SimpleTransformConverter(
+        ["tag:stsci.edu:asdf/transform/schechter1d-*"],
+        "astropy.modeling.powerlaws.Schechter1D",
+    ),
 ]
 
-if minversion("astropy", "5.1.0"):
-    TRANSFORM_CONVERTERS.append(
-        SimpleTransformConverter(
-            ["tag:stsci.edu:asdf/transform/schechter1d-*"],
-            "astropy.modeling.powerlaws.Schechter1D",
-        ),
-    )
-
-
 # The order here is important; asdf will prefer to use extensions
 # that occur earlier in the list.
 TRANSFORM_MANIFEST_URIS = [
+    "asdf://asdf-format.org/transform/manifests/transform-1.6.0",
     "asdf://asdf-format.org/transform/manifests/transform-1.5.0",
     "asdf://asdf-format.org/transform/manifests/transform-1.4.0",
     "asdf://asdf-format.org/transform/manifests/transform-1.3.0",
@@ -407,7 +405,6 @@ TRANSFORM_MANIFEST_URIS = [
     "asdf://asdf-format.org/transform/manifests/transform-1.0.0",
 ]
 
-
 TRANSFORM_EXTENSIONS = [
     ManifestExtension.from_uri(
         uri,
@@ -482,16 +479,28 @@ ASTROPY_CONVERTERS = [
     AstropyTableConverter(),
     AstropyFitsConverter(),
     NdarrayMixinConverter(),
+    UncertaintyConverter(),
+    WCSConverter(),
+    SlicedWCSConverter(),
+]
+
+_COORDINATES_MANIFEST_URIS = [
+    "asdf://asdf-format.org/astronomy/coordinates/manifests/coordinates-1.1.0",
+    "asdf://asdf-format.org/astronomy/coordinates/manifests/coordinates-1.0.0",
+]
+
+COORDINATES_EXTENSIONS = [
+    ManifestExtension.from_uri(
+        manifest_uri,
+        converters=COORDINATES_CONVERTERS,
+    )
+    for manifest_uri in _COORDINATES_MANIFEST_URIS
 ]
 
 
-COORDINATES_EXTENSION = ManifestExtension.from_uri(
-    "asdf://asdf-format.org/astronomy/coordinates/manifests/coordinates-1.0.0",
-    converters=COORDINATES_CONVERTERS,
-)
-
-
 _ASTROPY_EXTENSION_MANIFEST_URIS = [
+    "asdf://astropy.org/astropy/manifests/astropy-1.3.0",
+    "asdf://astropy.org/astropy/manifests/astropy-1.2.0",
     "asdf://astropy.org/astropy/manifests/astropy-1.1.0",
     "asdf://astropy.org/astropy/manifests/astropy-1.0.0",
 ]
@@ -508,42 +517,78 @@ ASTROPY_EXTENSIONS = [
     for manifest_uri in _ASTROPY_EXTENSION_MANIFEST_URIS
 ]
 
+
 # These tags are part of the ASDF Standard,
 # but we want to override serialization here so that users can
 # work with nice astropy objects for those entities.
-
-CORE_CONVERTERS = [
-    QuantityConverter(),
-    TimeConverter(),
-    ColumnConverter(),
-    AsdfTableConverter(),
+_FITS_CONVERTERS = [
     AsdfFitsConverter(),
 ]
 
-UNIT_CONVETERS = [
+_TIME_CONVERTERS = [
+    TimeConverter(),
+]
+
+_TABLE_CONVERTERS = [
+    ColumnConverter(),
+    AsdfTableConverter(),
+]
+
+_UNIT_CONVERTERS = [
     UnitConverter(),
     EquivalencyConverter(),
     MagUnitConverter(),
+    QuantityConverter(),
 ]
 
+CORE_CONVERTERS = _FITS_CONVERTERS + _TIME_CONVERTERS + _TABLE_CONVERTERS + _UNIT_CONVERTERS
 
+UNIT_EXTENSIONS = [
+    ManifestExtension.from_uri(
+        "asdf://astropy.org/astropy/manifests/units-1.0.0",
+        converters=_UNIT_CONVERTERS,
+    ),
+]
+
+# up to asdf 1.5.0 many tags supported by asdf-astropy
+# were defined in core manifests
 CORE_MANIFEST_URIS = [
-    "asdf://asdf-format.org/core/manifests/core-1.0.0",
-    "asdf://asdf-format.org/core/manifests/core-1.1.0",
-    "asdf://asdf-format.org/core/manifests/core-1.2.0",
-    "asdf://asdf-format.org/core/manifests/core-1.3.0",
-    "asdf://asdf-format.org/core/manifests/core-1.4.0",
+    "asdf://asdf-format.org/astronomy/manifests/astronomy-1.0.0",
     "asdf://asdf-format.org/core/manifests/core-1.5.0",
-    "asdf://asdf-format.org/core/manifests/core-1.6.0",
+    "asdf://asdf-format.org/core/manifests/core-1.4.0",
+    "asdf://asdf-format.org/core/manifests/core-1.3.0",
+    "asdf://asdf-format.org/core/manifests/core-1.2.0",
+    "asdf://asdf-format.org/core/manifests/core-1.1.0",
+    "asdf://asdf-format.org/core/manifests/core-1.0.0",
 ]
 
+CORE_EXTENSIONS = [ManifestExtension.from_uri(u, converters=CORE_CONVERTERS) for u in CORE_MANIFEST_URIS]
 
-CORE_EXTENSIONS = [
-    CompoundManifestExtension(
-        [
-            ManifestExtension.from_uri(u, converters=CORE_CONVERTERS),
-            ManifestExtension.from_uri("asdf://astropy.org/astropy/manifests/units-1.0.0", converters=UNIT_CONVETERS),
-        ],
-    )
-    for u in CORE_MANIFEST_URIS
+
+# asdf-astropy 0.4.0 combined core and unit manifests
+# but registered them with the core uri
+# asdf-astropy 0.5.0 combined core and unit manifests
+# but registered them with the core uri with asdf-format.org
+# swapped with astropy.org
+# To avoid warnings for opening old files we register empty
+# extensions with the astropy.org uris here
+class _EmptyExtension(Extension):
+    def __init__(self, uri):
+        self._uri = uri
+
+    @property
+    def extension_uri(self):
+        return self._uri
+
+
+EMPTY_EXTENSIONS = [
+    _EmptyExtension(uri)
+    for uri in [
+        "asdf://astropy.org/core/extensions/core-1.5.0",
+        "asdf://astropy.org/core/extensions/core-1.4.0",
+        "asdf://astropy.org/core/extensions/core-1.3.0",
+        "asdf://astropy.org/core/extensions/core-1.2.0",
+        "asdf://astropy.org/core/extensions/core-1.1.0",
+        "asdf://astropy.org/core/extensions/core-1.0.0",
+    ]
 ]
